@@ -24,4 +24,4 @@ pkexec --disable-internal-agent env \
     QT_QPA_PLATFORM="wayland" \
     XDG_CURRENT_DESKTOP="$XDG_CURRENT_DESKTOP" \
     XDG_SESSION_TYPE="wayland" \
-    "/usr/bin/calamares" "-D6" "$@" > installation.log
+    "/usr/bin/calamares" "-d" "$@" > installation.log
